# Masthay Helpers

[![Masthay Helpers](https://edibleaspen.ediblecommunities.com/sites/default/files/images/article/hive-1.jpg)](https://en.wikipedia.org/wiki/Worker_bee#Worker_activities)

This is a project for various helper functions to increase efficiency.
Think of it like a collection of [worker bees performing different tasks](https://en.wikipedia.org/wiki/Worker_bee#Worker_activities).
PyPi page is [here](https://pypi.org/project/masthay-helpers/).

## Table of Contents
- [Installation](#installation)

## Installation
Right now, I only support linux, but if you have linux, it's just a simple
install.
```bash
pip install masthay_helpers
